aboutsummaryrefslogtreecommitdiff
path: root/libobjc/init.c
diff options
context:
space:
mode:
Diffstat (limited to 'libobjc/init.c')
-rw-r--r--libobjc/init.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libobjc/init.c b/libobjc/init.c
index f1fea812318..954fc9240ae 100644
--- a/libobjc/init.c
+++ b/libobjc/init.c
@@ -368,16 +368,16 @@ class_is_subclass_of_class (Class class, Class superclass)
superclasses are not yet know to the runtime. */
static struct objc_list* unresolved_classes = 0;
/* Static function used to reference the Object and NXConstantString classes.
*/
-static void
+
+extern void __objc_force_linking (void);
+
+void
__objc_force_linking (void)
{
extern void __objc_linking (void);
__objc_linking ();
-
- /* Call the function to avoid compiler warning */
- __objc_force_linking ();
}
/* Run through the statics list, removing modules as soon as all its statics
@@ -368,16 +368,16 @@ class_is_subclass_of_class (Class class, Class superclass)
superclasses are not yet know to the runtime. */
static struct objc_list* unresolved_classes = 0;
-/* Static function used to reference the Object and NXConstantString classes.
+/* Extern function used to reference the Object and NXConstantString classes.
*/